package com.sooka.system.service.impl;

import java.util.List;

import com.sooka.common.annotation.DataSource;
import com.sooka.common.core.text.Convert;
import com.sooka.common.enums.DataSourceType;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.sooka.system.mapper.TgjjGrdkzhxxMapper;
import com.sooka.system.domain.TgjjGrdkzhxx;
import com.sooka.system.service.ITgjjGrdkzhxxService;

/**
 * 个人贷款账户信息Service业务层处理
 *
 * @author lei
 * @date 2021-11-16
 */
@Service
public class TgjjGrdkzhxxServiceImpl extends Guiji_Base_Service implements ITgjjGrdkzhxxService
{
    @Autowired
    private TgjjGrdkzhxxMapper tgjjGrdkzhxxMapper;

    /**
     * 查询个人贷款账户信息
     *
     * @param ID 个人贷款账户信息ID
     * @return 个人贷款账户信息
     */
    @Override
    public TgjjGrdkzhxx selectTgjjGrdkzhxxById(Long ID)
    {
        return tgjjGrdkzhxxMapper.selectTgjjGrdkzhxxById(ID);
    }

    /**
     * 查询个人贷款账户信息列表
     *
     * @param tgjjGrdkzhxx 个人贷款账户信息
     * @return 个人贷款账户信息
     */
    @Override
    public List<TgjjGrdkzhxx> selectTgjjGrdkzhxxList(TgjjGrdkzhxx tgjjGrdkzhxx)
    {
        List ls =tgjjGrdkzhxxMapper.selectTgjjGrdkzhxxList(tgjjGrdkzhxx);
        tgjjGrdkzhxx.setInterfaceinfoId("38576200-6b2e-4931-a724-6acdbe96f891");
        tgjjGrdkzhxx.setInterfaceinfoName("共享-市公积金-个人贷款账户信息");
        tgjjGrdkzhxx.setInterfacetype("platform_interfacetype_1");
        add_log(tgjjGrdkzhxx);
        return ls;
    }

    /**
     * 新增个人贷款账户信息
     *
     * @param tgjjGrdkzhxx 个人贷款账户信息
     * @return 结果
     */
    @Override
    public int insertTgjjGrdkzhxx(TgjjGrdkzhxx tgjjGrdkzhxx)
    {
        return tgjjGrdkzhxxMapper.insertTgjjGrdkzhxx(tgjjGrdkzhxx);
    }

    /**
     * 修改个人贷款账户信息
     *
     * @param tgjjGrdkzhxx 个人贷款账户信息
     * @return 结果
     */
    @Override
    public int updateTgjjGrdkzhxx(TgjjGrdkzhxx tgjjGrdkzhxx)
    {
        return tgjjGrdkzhxxMapper.updateTgjjGrdkzhxx(tgjjGrdkzhxx);
    }

    /**
     * 删除个人贷款账户信息对象
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTgjjGrdkzhxxByIds(String ids)
    {
        return tgjjGrdkzhxxMapper.deleteTgjjGrdkzhxxByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除个人贷款账户信息信息
     *
     * @param ID 个人贷款账户信息ID
     * @return 结果
     */
    @Override
    public int deleteTgjjGrdkzhxxById(Long ID)
    {
        return tgjjGrdkzhxxMapper.deleteTgjjGrdkzhxxById(ID);
    }
}
